<!---
Please read this!

Before opening a new issue, make sure to search for keywords in the issues
filtered by the "bug" label:

- https://gitlab.com/unitelabs/connectors/awesome-instrument/issues?label_name%5B%5D=bug

and verify the issue you're about to submit isn't a duplicate.
--->

### Your Development Environment

<!-- Provide detailed, anonymized information about your environment, including: OS, Python installation, package/service versions, and the make, model, software and firmware versions of the instrument (if any) relevant to the issue. -->

### Steps to Reproduce

Please provide a [Minimal Reproducible Example](https://stackoverflow.com/help/minimal-reproducible-example). If we cannot reproduce your problem, we cannot help fix it.

<!-- Describe how one can reproduce the issue - this is very important. Please use an ordered list. -->

### Current Bug Behavior

<!-- Describe what actually happens. -->

### Expected *Correct* Behavior

<!-- Describe what you should see instead. -->

### Relevant Logs and/or Output

<details>
<summary>Show Log / Output</summary>

```python
print("My code / logs should replace this sample code.")
```

<!-- Paste any relevant logs - please use code blocks (```) marked with the appropriate language after the first group of backticks to format console output, logs, and code as it's tough to read otherwise. -->

</details>

### Technical Hints

<!-- If you can, link to the line of code that might be responsible for the problem. -->

/label ~"bug"
